# A plugin of nonebot2

You just need to use pip to install it. 

If you want to know how to use it, check the file [README.md](https://github.com/HuParry/nonebot-plugin-cp-broadcast/blob/master/README.md)